/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or (at
 *  your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 *  MA 02110-1301, USA.
 *
 *  Copyright © 2006 Pierre Habouzit
 */
/*
 * Copyright notice from original mutt:
 * Copyright (C) 1996-2000 Michael R. Elkins <me@mutt.org>
 * Copyright (C) 1999-2000 Thomas Roessler <roessler@does-not-exist.org>
 *
 * This file is part of mutt-ng, see http://www.muttng.org/.
 * It's licensed under the GNU General Public License,
 * please see the file GPL in the top level source directory.
 */

/*
 * File manipulations + saner libgen functions
 */

#ifndef MUTT_LIB_LIB_FILE_H
#define MUTT_LIB_LIB_FILE_H

/****************************************************************************/
/* fd ops                                                                   */
/****************************************************************************/

int safe_open(const char *, int);
int safe_symlink(const char *, const char *);
int safe_rename(const char *, const char *);
void mutt_unlink(const char *);

/****************************************************************************/
/* FILE* ops                                                                */
/****************************************************************************/

FILE *safe_fopen(const char *, const char *);
int mutt_rename_file(char *, char *);
int safe_fclose(FILE **);

char *mutt_read_line(char *, ssize_t *, FILE *, int *);

int mutt_copy_stream(FILE *, FILE *);
int mutt_copy_bytes(FILE *, FILE *, ssize_t);

/****************************************************************************/
/* ligben-like funcs                                                        */
/****************************************************************************/

const char *mutt_basename(const char *);
char *mutt_concat_path(char *, ssize_t, const char *, const char *);

void mutt_sanitize_filename(char *, short);
ssize_t mutt_quote_filename(char *, ssize_t, const char *);

/* replace any %s with src, or appends " $src" */
ssize_t m_file_fmt(char *dst, ssize_t n, const char *fmt, const char *src);
int m_tempfd(char *dst, ssize_t n, const char *dir, const char *fmt);
FILE *m_tempfile(char *dst, ssize_t n, const char *dir, const char *fmt);

#endif /* MUTT_LIB_LIB_FILE_H */
